#
# spec file for package libgadu
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 3
Name:           libgadu
Version:        1.12.2
Release:        2.30
Summary:        Library for Handling of Gadu-Gadu Instant Messaging
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            http://toxygen.net/libgadu/
Source:         http://github.com/wojtekka/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  ca-certificates
BuildRequires:  doxygen
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(zlib)
# these packages are necessary for tests, but not necessary for a library:
# libexpat-devel, pkgconfig(libcurl), pkgconfig(libxml-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libgadu is a library for handling of protocol of a popular Polish
instant messenger Gadu-Gadu.

%package -n %{name}%{soname}
Summary:        Library for Handling of Gadu-Gadu Instant Messaging
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{name}%{soname}
libgadu is a library for handling of protocol of a popular Polish
instant messenger Gadu-Gadu.

%package devel
Summary:        Library for Handling of Gadu-Gadu Instant Messaging
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}
Requires:       glibc-devel

%description devel
libgadu is a library for handling of protocol of a popular Polish
instant messenger Gadu-Gadu.

%prep
%setup -q

%build
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
# remove installdox from html dir
rm -f docs/html/installdox
#
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%doc docs/html
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat May 25 2019 Mariusz Fik <fisiu@opensuse.org>
- Build against zlib.
* Tue Jun  6 2017 fisiu@opensuse.org
- Update to version 1.12.2, bugfix release:
  + fixes overwriting memory when updating contacts list
  + fixes TLS connection and improve gnutls errors handling
  + fixes disconnection when joining to room with title set
  + other small fixes
* Tue Feb  3 2015 fisiu@opensuse.org
- Update to version 1.12.1, bugfix release:
  + improved compatibility with GG11 protocol
  + fix segfaults when got incorrect reply from public catalog
  + fixes related to proxy servers
* Tue Jun 17 2014 twasilczyk@pidgin.im
- Update to version 1.12.0:
  + supports GG11 protocol
  + important SSL-related API improvements
  + OpenSSL is disabled by default
  + pthread is a default hostname resolving method now
  + stability improvements
- Updated dependencies
  + libgsm and speex are not used at all
  + libexpat, libcurl and libxml are used only for automatic tests
  + libprotobuf-c is an optional dependency
- Removed unnecessary --with-pthread switch (it's default now)
* Sun May 11 2014 fisiu@opensuse.org
- Update to version 1.11.4, bugfix release:
  + Fix buffer overflow with remote code execution potential.
    Only triggerable by a Gadu-Gadu server or a man-in-the-middle.
    CVE-2013-6487 (bnc#861019, bnc#878540)
  + Fix memory overwrite in file transfer with proxy server.
    CVE-2014-3775 (bnc#878540)
  + Minor fixes reported by Pidgin project members.
* Tue Jun 19 2012 fisiu@opensuse.org
- Update to version 1.11.2, bugfix release:
  + improved hostname resolving in singlethread applications.
* Thu Jan 19 2012 fisiu@opensuse.org
- Update to version 1.11.1, bugfix release:
  + improved SSL support with GnuTLS library
  + improved pkg-config handling
  + improved conversion of invalid UTF-8 sequence
  + improved hostname resolving on systems without gethostbyname_r()
* Fri Dec 30 2011 sbrabec@suse.cz
- Apply /usr/local include work-around for 12.1 only (bnc#719176).
* Mon Dec  5 2011 fisiu@opensuse.org
- Fix include path (/usr/local) in .pc file.
- Replace -devel with pkgconfig() in BuildRequires.
- Fix license notation according to spdx.
* Fri Jun 17 2011 vuntz@opensuse.org
- Change pkgconfig(openssl) BuildRequires to gnutls-devel as this
  seems to be preferred.
- Add curl-devel, libexpat-devel, libgsm-devel, speex-devel and
  pkgconfig(libxml-2.0) BuildRequires, to enable optional features.
* Thu Jun  9 2011 fisiu@opensuse.org
- Update to version 1.11.0:
  + contacts import/export compatible with gadu-gadu 10
  + improved sockets management with direct connections
  + detailed report when connection fails
  + enhanced confirmation for delivered message
  + improved message conversion from html to plain text
* Fri Mar 18 2011 fisiu@opensuse.org
- Update to version 1.10.1:
  + improved direct connections
  + improved connections over proxy server
  + some minor changes
* Fri Feb 18 2011 fisiu@opensuse.org
- Update to version 1.10.0:
  + ssl connections restored
  + typing notifications
  + multilogin support
  + buddies' info enhancement
  + support for additional xml events
  + initial file transfer over server
  + partial import of new-api branch
- Spec cleanup.
* Sat Oct  9 2010 fisiu@opensuse.org
- Update to version 1.9.1:
  + fixed memory leak in html messages
  + improved converting messages to html
  + status flag can be changed now
  + improved direct connection API
- Drop libgadu-mem-leak-fix.patch: fixed upstream.
* Sun May 23 2010 fisiu@opensuse.org
- Update to version 1.9.0:
  + support for new version of gadu-gadu protocol (8 and 10)
  + images sending fixed
  + resolve name schema option
  + doc and test programs
- Add libgadu-mem-leak-fix.patch.
* Mon Jul 27 2009 sbrabec@suse.cz
- Build with threads support (bnc#525312) and SSL support.
* Wed Oct 29 2008 sbrabec@suse.cz
- Updated to version 1.8.2:
  * fixes remote denial of service via contact description
    (CVE-2008-4776, bnc#439770)
* Tue Aug 19 2008 sbrabec@suse.cz
- Updated to version 1.8.1:
  * fixed memory corruption in gg_dcc7_send_file()
  * fixes in sending cached data
  * endian fixes
  * documentation fixes
* Sat Mar  8 2008 crrodriguez@suse.de
- update to version 1.8.0
  * using protocol Gadu-Gadu 7.x
  * direct connection fixes
  * minor fixes
- disable static libraries
* Fri May 11 2007 aj@suse.de
- Remove duplicate post/postun sections.
* Thu May 10 2007 sbrabec@suse.cz
- New SuSE package, version 1.7.1.
